@@ -110,7 +110,7 @@ gkb_prop_map_apply_clicked (GkbMapDialogInfo * mdi)
 
   gkb_apply(mdi->pbi);   
 
-  applet_save_session();
+  applet_save_session(mdi->pbi->gkb);
 
   gtk_widget_set_sensitive (mdi->apply_button, FALSE);
   mdi->changed = FALSE;
@@ -128,7 +128,7 @@ gkb_prop_map_close_clicked (GkbMapDialogInfo * mdi)
 {
   gtk_widget_destroy (mdi->dialog);
 
-  applet_save_session();
+  applet_save_session(mdi->pbi->gkb);
    
   mdi->dialog = NULL;
 }
@@ -492,7 +492,7 @@ gkb_prop_map_combo_at (GtkWidget * table, gint row, gint col,
   g_signal_connect (entry, "changed",
 		      G_CALLBACK (gkb_prop_map_data_changed), mdi);
 
-  gtk_label_set_mnemonic_widget(GTK_LABEL(label_prop_map), entry);
+  gtk_label_set_mnemonic_widget(GTK_LABEL(label_prop_map), entry); 
   if (gail_loaded)
     {
       add_atk_relation(combo, label_prop_map, ATK_RELATION_LABELLED_BY);
@@ -529,10 +529,10 @@ gkb_prop_map_pixmap_at (GtkWidget * table, gint row, gint col,
 		      "changed", G_CALLBACK (gkb_prop_map_data_changed),
 		      mdi);
   
+  gtk_label_set_mnemonic_widget(GTK_LABEL(label_prop_map), icon_entry); 
   if (gail_loaded)
   {
     add_atk_relation(icon_entry, label_prop_map, ATK_RELATION_LABELLED_BY);
-    add_atk_relation(label_prop_map, icon_entry, ATK_RELATION_LABEL_FOR);
   }
   return icon_entry;
 }
@@ -628,7 +628,7 @@ gkb_prop_map_edit (GkbPropertyBoxInfo * pbi)
   mdi->country_entry = entry;
   g_list_free (list);
 
-  gkb_prop_map_label_at (right_table, 0, 4, _("Flag\nPixmap"));
+  gkb_prop_map_label_at (right_table, 0, 4, _("_Flag\nPixmap:"));
   mdi->icon_entry =
     gkb_prop_map_pixmap_at (right_table, 1, 4, mdi, keymap->flag);
 
