@@ -66,6 +66,7 @@ void
 gkb_apply (GkbPropertyBoxInfo * pbi)
 {
   gint selected;
+  GKB *gkb = pbi->gkb;
   /* Swap the lists of keymaps */
   gkb_keymap_free_list (gkb->maps);
   gkb->maps = gkb_keymap_copy_list (pbi->keymaps);
@@ -165,6 +166,7 @@ static void
 gkb_prop_mode_changed (GtkWidget * menu_item, GkbPropertyBoxInfo * pbi)
 {
   gchar *text;
+  GKB *gkb = pbi->gkb;
 
   text = gtk_object_get_data (GTK_OBJECT (menu_item), GKB_MENU_ITEM_TEXT);
 
@@ -190,6 +192,7 @@ static void
 gkb_prop_size_changed (GtkWidget * menu_item, GkbPropertyBoxInfo * pbi)
 {
   gchar *text;
+  GKB *gkb = pbi->gkb;
 
   text = gtk_object_get_data (GTK_OBJECT (menu_item), GKB_MENU_ITEM_TEXT);
 
@@ -336,6 +339,7 @@ gkb_prop_create_hotkey_frame (GkbPropertyBoxInfo * pbi, GtkWidget * widget)
   GtkWidget *frame;
   GtkWidget *button;
   GtkWidget *hbox;
+  GKB *gkb = pbi->gkb;
 
   frame = gtk_frame_new (_("Hotkey for switching between layouts"));
   hbox = gtk_hbox_new (TRUE, 0);
@@ -349,7 +353,7 @@ gkb_prop_create_hotkey_frame (GkbPropertyBoxInfo * pbi, GtkWidget * widget)
   pbi->hotkey_entry = gtk_entry_new ();
   gtk_entry_set_text (GTK_ENTRY (pbi->hotkey_entry), gkb->key);
 
-  button = gtk_button_new_with_label (_("Grab hotkey"));
+  button = gtk_button_new_with_mnemonic (_("_Grab hotkey"));
   if (gail_loaded)                                                              
     {                                                                           
       add_atk_relation(GTK_WIDGET(pbi->hotkey_entry),
@@ -365,7 +369,7 @@ gkb_prop_create_hotkey_frame (GkbPropertyBoxInfo * pbi, GtkWidget * widget)
 */
   g_signal_connect (button, "clicked",
 		      G_CALLBACK (grab_button_pressed),
-		      pbi->hotkey_entry);
+		      pbi);
 
   return frame;
 }
@@ -380,17 +384,17 @@ prophelp_cb (GtkWidget *widget, gpointer data)
 static void
 window_response (GtkWidget *w, int response, gpointer data)
 {
-  GkbPropertyBoxInfo * pbi = data;	
+  GkbPropertyBoxInfo * pbi = data;
+  GKB *gkb = pbi->gkb;
+
   if (response == GTK_RESPONSE_HELP)
     prophelp_cb (gkb->applet, data);
   else {
-#if 0
     gtk_list_store_clear (GTK_LIST_STORE (gtk_tree_view_get_model 
                           (GTK_TREE_VIEW (pbi->list))));
     g_free (pbi);
     gtk_widget_destroy (w);
-#endif
-    gtk_widget_hide (propwindow);
+    propwindow = NULL;
   }
        
 }
@@ -455,34 +459,14 @@ gkb_prop_create_property_box (GkbPropertyBoxInfo * pbi)
   return propwindow;
 }
 
-static gint
-gkb_prop_box_destroy (GtkWidget * box, GkbPropertyBoxInfo * pbi)
-{
-  g_return_val_if_fail (pbi != NULL, TRUE);
-  g_return_val_if_fail (box == pbi->box, TRUE);
-
-  gtk_widget_destroy (GTK_WIDGET (box));
-  /* This is hackish, but I could not find the correct
-   * solution for it. The problem is that when we destroy
-   * the list, the selection changes if there is a selected
-   * row, so we need to clear the selection so that the
-   * gkb_prop_list_selection_changed function is not reached.
-   * if you know of a way to solve this, enlighten me. Chema */
-  gtk_list_store_clear (GTK_LIST_STORE (gtk_tree_view_get_model 
-                        (GTK_TREE_VIEW (pbi->list))));
-  g_free (pbi);
-
-  return FALSE;
-}
-
-void
+void	
 properties_dialog (BonoboUIComponent *uic,
 	           GKB       *gkb,
 	           const gchar	  *verbname)
 {
   GkbPropertyBoxInfo *pbi;
   
-  if (propwindow != NULL) {
+  if (propwindow) {
   	gtk_window_present (GTK_WINDOW (propwindow));
   	return;
   }
@@ -502,7 +486,6 @@ properties_dialog (BonoboUIComponent *uic,
   pbi->box = gkb_prop_create_property_box (pbi);
 
   gtk_widget_show_all (pbi->box);
-  gdk_window_raise (pbi->box->window);
-
+  
   return;
 }
